@@ -17,3 +17,13 @@ class DocumentManager(RESTManager):
         path = f"{self.path}/" + document_id + "/file"
         result = self.openbas.http_get(path, **kwargs)
         return result
+
+    @exc.on_http_error(exc.OpenBASUpdateError)
+    def upsert(
+        self, document: Dict[str, Any], file: tuple, **kwargs: Any
+    ) -> Dict[str, Any]:
+        path = f"{self.path}/upsert"
+        result = self.openbas.http_post(
+            path, post_data=document, files={"file": file}, **kwargs
+        )
+        return result
