@@ -1,18 +1,24 @@
 from typing import List
 
-from pyobas.contracts.contract_config import ContractElement
+from pyobas.contracts.contract_config import ContractElement, ContractOutputElement
 
 
 class ContractBuilder:
     fields: List[ContractElement]
+    outputs: List[ContractOutputElement]
 
     def __init__(self):
         self.fields = []
+        self.outputs = []
 
     def add_fields(self, fields: List[ContractElement]):
         self.fields = self.fields + fields
         return self
 
+    def add_outputs(self, outputs: List[ContractOutputElement]):
+        self.outputs = self.outputs + outputs
+        return self
+
     def mandatory(self, element: ContractElement):
         element.mandatory = True
         self.fields.append(element)
@@ -31,5 +37,8 @@ class ContractBuilder:
             self.fields.append(element)
         return self
 
-    def build(self) -> List[ContractElement]:
+    def build_fields(self) -> List[ContractElement]:
         return self.fields
+
+    def build_outputs(self) -> List[ContractOutputElement]:
+        return self.outputs
