@@ -14,7 +14,7 @@ class SupportedLanguage(str, Enum):
     en: str = "en"
 
 
-class ContractType(str, Enum):
+class ContractFieldType(str, Enum):
     Text: str = "text"
     Number: str = "number"
     Tuple: str = "tuple"
@@ -32,13 +32,25 @@ class ContractType(str, Enum):
     Payload: str = "payload"
 
 
+class ContractOutputType(str, Enum):
+    Text: str = "text"
+    Number: str = "number"
+    Port: str = "port"
+    PortsScan: str = "portscan"
+    IPv4: str = "ipv4"
+    IPv6: str = "ipv6"
+    CVE: str = "cve"
+
+
 class ExpectationType(str, Enum):
     text: str = "TEXT"
     document: str = "DOCUMENT"
     article: str = "ARTICLE"
     challenge: str = "CHALLENGE"
     manual: str = "MANUAL"
-    technical: str = "TECHNICAL"
+    prevention: str = "PREVENTION"
+    detection: str = "DETECTION"
+    vulnerability: str = "VULNERABILITY"
 
 
 @dataclass
@@ -53,7 +65,7 @@ class Expectation:
 @dataclass
 class LinkedFieldModel:
     key: str
-    type: ContractType
+    type: ContractFieldType
 
 
 @dataclass
@@ -62,6 +74,8 @@ class ContractElement(ABC):
     label: str
     type: str = field(default="", init=False)
     mandatoryGroups: List[str] = None
+    mandatoryConditionField: str = None
+    mandatoryConditionValue: str = None
     linkedFields: List["ContractElement"] = field(default_factory=list)
     linkedValues: List[str] = field(default_factory=list)
     mandatory: bool = False
@@ -82,6 +96,15 @@ class ContractCardinalityElement(ContractElement, ABC):
     defaultValue: List[str] = field(default_factory=list)
 
 
+@dataclass
+class ContractOutputElement(ABC):
+    type: str
+    field: str
+    labels: List[str]
+    isFindingCompatible: bool
+    isMultiple: bool
+
+
 @dataclass
 class ContractConfig:
     type: str
@@ -96,6 +119,7 @@ class Contract:
     contract_id: str
     label: dict[SupportedLanguage, str]
     fields: List[ContractElement]
+    outputs: List[ContractOutputElement]
     config: ContractConfig
     manual: bool
     variables: List[ContractVariable] = field(
@@ -121,7 +145,7 @@ class Contract:
 class ContractTeam(ContractCardinalityElement):
     @property
     def get_type(self) -> str:
-        return ContractType.Team.value
+        return ContractFieldType.Team.value
 
 
 @dataclass
@@ -131,7 +155,7 @@ class ContractText(ContractCardinalityElement):
 
     @property
     def get_type(self) -> str:
-        return ContractType.Text.value
+        return ContractFieldType.Text.value
 
 
 def prepare_contracts(contracts):
@@ -161,7 +185,7 @@ class ContractTuple(ContractCardinalityElement):
 
     @property
     def get_type(self) -> str:
-        return ContractType.Tuple.value
+        return ContractFieldType.Tuple.value
 
 
 @dataclass
@@ -172,7 +196,7 @@ class ContractTextArea(ContractCardinalityElement):
 
     @property
     def get_type(self) -> str:
-        return ContractType.Textarea.value
+        return ContractFieldType.Textarea.value
 
 
 @dataclass
@@ -182,7 +206,7 @@ class ContractCheckbox(ContractElement):
 
     @property
     def get_type(self) -> str:
-        return ContractType.Checkbox.value
+        return ContractFieldType.Checkbox.value
 
 
 @dataclass
@@ -190,7 +214,7 @@ class ContractAttachment(ContractCardinalityElement):
 
     @property
     def get_type(self) -> str:
-        return ContractType.Attachment.value
+        return ContractFieldType.Attachment.value
 
 
 @dataclass
@@ -200,7 +224,7 @@ class ContractExpectations(ContractCardinalityElement):
 
     @property
     def get_type(self) -> str:
-        return ContractType.Expectation.value
+        return ContractFieldType.Expectation.value
 
 
 @dataclass
@@ -210,7 +234,7 @@ class ContractSelect(ContractCardinalityElement):
 
     @property
     def get_type(self) -> str:
-        return ContractType.Select.value
+        return ContractFieldType.Select.value
 
 
 @dataclass
@@ -218,7 +242,7 @@ class ContractAsset(ContractCardinalityElement):
 
     @property
     def get_type(self) -> str:
-        return ContractType.Asset.value
+        return ContractFieldType.Asset.value
 
 
 @dataclass
@@ -226,7 +250,7 @@ class ContractAssetGroup(ContractCardinalityElement):
 
     @property
     def get_type(self) -> str:
-        return ContractType.AssetGroup.value
+        return ContractFieldType.AssetGroup.value
 
 
 @dataclass
@@ -234,4 +258,4 @@ class ContractPayload(ContractCardinalityElement):
 
     @property
     def get_type(self) -> str:
-        return ContractType.Payload.value
+        return ContractFieldType.Payload.value
